/* Last modified: January 20, 2015

*--------------------*
*      OVERVIEW      *
*--------------------*

* Iterates through all possible contiguous time periods and estimates 
* ln(minimum wage) effect on job growth. Done in the BDS and QCEW.

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata by typing "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html

Files needed: 

bds.dta - a cleaned version of the Business Dyanamics Statistics, linked to State minimum wage data and other covariates

qcew.dta - a cleaned version of the Quarterly Census of Employment and Wages, linked to State minimum wage data and other covariates

*/


*------------------------------*
*  All firms: job growth       *
*------------------------------*

clear all
set more off
set matsize 2000

* BDS:

use bds , clear
gen tempmw = lnmin if year == 1977
egen initmw = min(tempmw) , by(statefips)
drop tempmw
fvset base 1 state
fvset base 1 year
qui reg D.lemp lnmin initmw i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap
estimates store result
esttab result using histogram_time_period_coef_BDS.csv , replace b(4) keep(lnmin) ///
coeflabel(lnmin "1977 to 2011") not nomtitles nostar nonotes nogap noobs nonum

forv beginyear = 1977/2010 {
local end = `beginyear' + 1
qui forv endyear = `end'/2011 {
estimates clear
qui reg D.lemp lnmin initmw i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap if year >= `beginyear' & year <= `endyear'
estimates store result
esttab result using histogram_time_period_coef_BDS.csv , append b(4) keep(lnmin) ///
coeflabel(lnmin "`beginyear' to `endyear'") not nomtitles nostar nonotes nogap noobs nonum
}
display "Year `beginyear' complete"
}

insheet using "histogram_time_period_coef_BDS.csv" , delimit(",") clear
duplicates drop // Duplicate value of the full span 1977-2011
rename v1 yearspan
rename v2 coef
split(yearspan) , parse(" to ")
drop yearspan
destring yearspan* , force replace
rename yearspan1 firstyear
rename yearspan2 lastyear
gen span = 1 + lastyear - firstyear

sort coef
gen rankcoef = _n / _N

gen temp = coef - 0
replace temp = . if coef < 0
egen mtemp = min(temp)
gen pctabv0 = rankcoef if temp == mtemp
drop temp mtemp

gen temp = 0 - coef
replace temp = . if coef > 0
egen mtemp = min(temp)
gen pctbelow0 = rankcoef if temp == mtemp
drop temp mtemp

gen positivecoef = (coef>0)
tab span positivecoef

tab pctbelow0
tab pctabv0
tab coef if pctab != . | pctbel != .

su coef , d

tab coef if coef < -0.2 // 35
tab coef if coef > 0.2 // 8

#delimit ;
hist coef if abs(coef) <= 0.2 , width(0.001) xline(0) frac xlab(-0.2(0.1)0.2)
graphregion(color(white)) bcolor(gs12)
ytitle("Fraction of coefficients") xtitle("Estimated effect of log minimum wage on annual job growth")
note("For clarity, we trimmed 35 observations less than -0.2 and 8 observations greater than 0.2")
;
#delimit cr

graph export Fig-histogram-time-periods-BDS.png , width(1000) replace


********
* QCEW

use qcew , clear
keep if industry == 10 // All ages in all industries in all sectors and ownership
gen tempmw = lnmin if year == 1975 & quarter == 1
egen initmw = min(tempmw) , by(statefips)
drop tempmw
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settingss

qui reg D.lemp lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap
estimates store result
esttab result using histogram_time_period_coef_QCEW.csv , replace b(4) keep(lnmin) ///
coeflabel(lnmin "1975Q2 to 2012Q4") not nomtitles nostar nonotes nogap noobs nonum

forv beginyear = 1975/2011 { // If quarterly, 61 through 192, but this wouldn't add much except taking a lot more time
local end = `beginyear' + 1
qui forv endyear = `end'/2012 {
qui reg D.lemp lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap if year >= `beginyear' & year <= `endyear'
estimates store result
esttab result using histogram_time_period_coef_QCEW.csv , append b(4) keep(lnmin) ///
coeflabel(lnmin "`beginyear' to `endyear'") not nomtitles nostar nonotes nogap noobs nonum
}
display "Year `beginyear' complete"
}



insheet using "histogram_time_period_coef_QCEW.csv" , delimit(",") clear
duplicates drop  // Duplicate value of the full span 1975-2012
rename v1 yearspan
rename v2 coef
split(yearspan) , parse(" to ")
drop yearspan
destring yearspan* , force replace
rename yearspan1 firstyear
rename yearspan2 lastyear
gen span = 1 + lastyear - firstyear

sort coef
gen rankcoef = _n / _N

gen temp = coef - 0
replace temp = . if coef < 0
egen mtemp = min(temp)
gen pctabv0 = rankcoef if temp == mtemp
drop temp mtemp

gen temp = 0 - coef
replace temp = . if coef > 0
egen mtemp = min(temp)
gen pctbelow0 = rankcoef if temp == mtemp
drop temp mtemp

gen positivecoef = (coef>0)
tab span positivecoef

tab pctbelow0
tab pctabv0
tab coef if pctab != . | pctbel != .

su coef , d

tab coef if coef < -0.1 // 2
tab coef if coef > 0.1 // 12

#delimit ;
hist coef if abs(coef) <= 0.1 , width(0.001) xline(0) frac xlab(-0.1(0.05)0.1)
graphregion(color(white)) bcolor(gs12)
ytitle("Fraction of coefficients") xtitle("Estimated effect of log minimum wage on quarterly job growth")
note("For clarity, we trimmed 2 observations less than -0.1 and 12 observations greater than 0.1")
;
#delimit cr

graph export Fig-histogram-time-periods-QCEW.png , width(1000) replace

window manage close graph
